==> camunda-engine-7.8.0-sources.jar: org/camunda/bpm/engine/impl/pvm/runtime/OutgoingExecution.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.camunda.bpm.engine.impl.pvm.runtime;

import org.camunda.bpm.engine.impl.pvm.PvmLogger;
import org.camunda.bpm.engine.impl.pvm.PvmTransition;

/**
 *
 * @author Tom Baeyens
 * @author Daniel Meyer
 */
public class OutgoingExecution {

  private final static PvmLogger LOG = PvmLogger.PVM_LOGGER;

  protected PvmExecutionImpl outgoingExecution;
  protected PvmTransition outgoingTransition;

  public OutgoingExecution(PvmExecutionImpl outgoingExecution, PvmTransition outgoingTransition) {
    this.outgoingExecution = outgoingExecution;
    this.outgoingTransition = outgoingTransition;
    outgoingExecution.setTransition(outgoingTransition);
  }

  public void take() {
    if (outgoingExecution.getReplacedBy() != null) {
      outgoingExecution = outgoingExecution.getReplacedBy();
    }
    if(!outgoingExecution.isEnded()) {
      outgoingExecution.take();
    } else {
      LOG.notTakingTranistion(outgoingTransition);
    }
  }
}

==> camunda-engine-7.9.0-sources.jar: org/camunda/bpm/engine/impl/pvm/runtime/OutgoingExecution.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.camunda.bpm.engine.impl.pvm.runtime;

import org.camunda.bpm.engine.impl.pvm.PvmLogger;
import org.camunda.bpm.engine.impl.pvm.PvmTransition;

/**
 *
 * @author Tom Baeyens
 * @author Daniel Meyer
 */
public class OutgoingExecution {

  private final static PvmLogger LOG = PvmLogger.PVM_LOGGER;

  protected PvmExecutionImpl outgoingExecution;
  protected PvmTransition outgoingTransition;

  public OutgoingExecution(PvmExecutionImpl outgoingExecution, PvmTransition outgoingTransition) {
    this.outgoingExecution = outgoingExecution;
    this.outgoingTransition = outgoingTransition;
    outgoingExecution.setTransition(outgoingTransition);
    outgoingExecution.setActivityInstanceId(null);
  }

  public void take() {
    if (outgoingExecution.getReplacedBy() != null) {
      outgoingExecution = outgoingExecution.getReplacedBy();
    }
    if(!outgoingExecution.isEnded()) {
      outgoingExecution.take();
    } else {
      LOG.notTakingTranistion(outgoingTransition);
    }
  }

  public PvmExecutionImpl getOutgoingExecution() {
    return outgoingExecution;
  }
}
